@@ -166,7 +166,7 @@ from sqlalchemy import types as sqltypes
 
 
 __all__ = (
-    'MSBigInteger', 'MSBinary', 'MSBit', 'MSBlob', 'MSBoolean',
+    'MSBigInteger', 'MSMediumInteger', 'MSBinary', 'MSBit', 'MSBlob', 'MSBoolean',
     'MSChar', 'MSDate', 'MSDateTime', 'MSDecimal', 'MSDouble',
     'MSEnum', 'MSFloat', 'MSInteger', 'MSLongBlob', 'MSLongText',
     'MSMediumBlob', 'MSMediumText', 'MSNChar', 'MSNVarChar',
@@ -548,6 +548,33 @@ class MSBigInteger(MSInteger):
         else:
             return self._extend("BIGINT")
 
+class MSMediumInteger(MSInteger):
+    """MySQL MEDIUMINTEGER type."""
+
+    def __init__(self, length=None, **kw):
+        """Construct a MEDIUMINTEGER
+
+        length
+          Optional, maximum display width for this number.
+
+        unsigned
+          Optional.
+
+        zerofill
+          Optional. If true, values will be stored as strings left-padded with
+          zeros. Note that this does not effect the values returned by the
+          underlying database API, which continue to be numeric.
+        """
+
+        super(MSMediumInteger, self).__init__(length, **kw)
+
+    def get_col_spec(self):
+        if self.length is not None:
+            return self._extend("MEDIUMINT(%(length)s)" % {'length': self.length})
+        else:
+            return self._extend("MEDIUMINT")
+
+
 
 class MSTinyInteger(MSInteger):
     """MySQL TINYINT type."""
@@ -1363,7 +1390,7 @@ ischema_names = {
     'longblob': MSLongBlob,
     'longtext': MSLongText,
     'mediumblob': MSMediumBlob,
-    'mediumint': MSInteger,
+    'mediumint': MSMediumInteger,
     'mediumtext': MSMediumText,
     'nchar': MSNChar,
     'nvarchar': MSNVarChar,
