@@ -23,7 +23,7 @@ import StringIO, weakref
 from sqlalchemy import util, logging, topological, exceptions
 from sqlalchemy.orm import attributes, interfaces
 from sqlalchemy.orm import util as mapperutil
-from sqlalchemy.orm.mapper import object_mapper, _state_mapper
+from sqlalchemy.orm.mapper import object_mapper, _state_mapper, has_identity
 
 # Load lazily
 object_session = None
@@ -33,35 +33,41 @@ class UOWEventHandler(interfaces.AttributeExtension):
     session cascade operations.
     """
 
-    def __init__(self, key, class_, cascade=None):
+    def __init__(self, key, class_, cascade):
         self.key = key
         self.class_ = class_
         self.cascade = cascade
+    
+    def _target_mapper(self, obj):
+        prop = object_mapper(obj).get_property(self.key)
+        return prop.mapper
 
     def append(self, obj, item, initiator):
         # process "save_update" cascade rules for when an instance is appended to the list of another instance
         sess = object_session(obj)
-        if sess is not None:
-            if self.cascade is not None and self.cascade.save_update and item not in sess:
-                mapper = object_mapper(obj)
-                prop = mapper.get_property(self.key)
-                ename = prop.mapper.entity_name
-                sess.save_or_update(item, entity_name=ename)
+        if sess:
+            if self.cascade.save_update and item not in sess:
+                sess.save_or_update(item, entity_name=self._target_mapper(obj).entity_name)
 
     def remove(self, obj, item, initiator):
-        # currently no cascade rules for removing an item from a list
-        # (i.e. it stays in the Session)
-        pass
+        sess = object_session(obj)
+        if sess:
+            # expunge pending orphans
+            if self.cascade.delete_orphan and item in sess.new:
+                if self._target_mapper(obj)._is_orphan(item):
+                    sess.expunge(item)
 
     def set(self, obj, newvalue, oldvalue, initiator):
         # process "save_update" cascade rules for when an instance is attached to another instance
+        if oldvalue is newvalue:
+            return
         sess = object_session(obj)
-        if sess is not None:
-            if newvalue is not None and self.cascade is not None and self.cascade.save_update and newvalue not in sess:
-                mapper = object_mapper(obj)
-                prop = mapper.get_property(self.key)
-                ename = prop.mapper.entity_name
-                sess.save_or_update(newvalue, entity_name=ename)
+        if sess:
+            if newvalue is not None and self.cascade.save_update and newvalue not in sess:
+                sess.save_or_update(newvalue, entity_name=self._target_mapper(obj).entity_name)
+            if self.cascade.delete_orphan and oldvalue in sess.new:
+                sess.expunge(oldvalue)
+
 
 def register_attribute(class_, key, *args, **kwargs):
     """overrides attributes.register_attribute() to add UOW event handlers
@@ -127,9 +133,13 @@ class UnitOfWork(object):
             
         if hasattr(state, 'insert_order'):
             delattr(state, 'insert_order')
-            
-        self.identity_map[state.dict['_instance_key']] = state.obj()
-        state.commit_all()
+        
+        o = state.obj()
+        # prevent against last minute dereferences of the object
+        # TODO: identify a code path where state.obj() is None
+        if o is not None:
+            self.identity_map[state.dict['_instance_key']] = o
+            state.commit_all()
         
         # remove from new last, might be the last strong ref
         self.new.pop(state, None)
@@ -173,15 +183,19 @@ class UnitOfWork(object):
         if not dirty and not self.deleted and not self.new:
             return
         
-        deleted = util.Set(self.deleted)
-        new = util.Set(self.new)
-        
-        dirty = util.Set(dirty).difference(deleted)
-        
         flush_context = UOWTransaction(self, session)
 
         if session.extension is not None:
             session.extension.before_flush(session, flush_context, objects)
+            dirty = [x for x in self.identity_map.all_states()
+                if x.modified
+                or (x.class_._class_state.has_mutable_scalars and x.is_modified())
+            ]
+
+        deleted = util.Set(self.deleted)
+        new = util.Set(self.new)
+        
+        dirty = util.Set(dirty).difference(deleted)
 
         # create the set of all objects we want to operate upon
         if objects:
@@ -199,7 +213,15 @@ class UnitOfWork(object):
             if state in processed:
                 continue
 
-            flush_context.register_object(state, isdelete=_state_mapper(state)._is_orphan(state.obj()))
+            obj = state.obj()
+            is_orphan = _state_mapper(state)._is_orphan(obj)
+            if is_orphan and not has_identity(obj):
+                raise exceptions.FlushError("instance %s is an unsaved, pending instance and is an orphan (is not attached to %s)" %
+                    (
+                        obj,
+                        ", nor ".join(["any parent '%s' instance via that classes' '%s' attribute" % (klass.__name__, key) for (key,klass) in _state_mapper(state).delete_orphans])
+                    ))
+            flush_context.register_object(state, isdelete=is_orphan)
             processed.add(state)
 
         # put all remaining deletes into the flush context.
@@ -216,10 +238,10 @@ class UnitOfWork(object):
             
             if session.extension is not None:
                 session.extension.after_flush(session, flush_context)
+            session.commit()
         except:
             session.rollback()
             raise
-        session.commit()
 
         flush_context.post_exec()
 
@@ -331,16 +353,6 @@ class UOWTransaction(object):
         taskelement = task._objects[state]
         taskelement.isdelete = "rowswitch"
         
-    def unregister_object(self, obj):
-        """remove an object from its parent UOWTask.
-        
-        called by mapper._save_obj() when an 'identity switch' is detected, so that
-        no further operations occur upon the instance."""
-        mapper = object_mapper(obj)
-        task = self.get_task_by_mapper(mapper)
-        if obj._state in task._objects:
-            task.delete(obj._state)
-
     def is_deleted(self, state):
         """return true if the given state is marked as deleted within this UOWTransaction."""
         
@@ -573,11 +585,6 @@ class UOWTask(object):
         # instead of __eq__
         self.mapper._save_obj([state], self.uowtransaction, postupdate=True, post_update_cols=util.Set(post_update_cols))
 
-    def delete(self, obj):
-        """remove the given object from this UOWTask, if present."""
-
-        self._objects.pop(obj._state, None)
-
     def __contains__(self, state):
         """return True if the given object is contained within this UOWTask or inheriting tasks."""
         
@@ -759,14 +766,14 @@ class UOWTask(object):
             make_task_tree(head, t, {})
 
         ret = [t]
+
+        # add tasks that were in the cycle, but didnt get assembled
+        # into the cyclical tree, to the start of the list
         for t2 in cycles:
             if t2 not in used_tasks and t2 is not self:
-                # add tasks that were in the cycle, but didnt get assembled
-                # into the cyclical tree, to the start of the list
-                # TODO: no test coverage for this !!
                 localtask = UOWTask(self.uowtransaction, t2.mapper)
                 for state in t2.elements:
-                    localtask.append(obj, t2.listonly, isdelete=t2._objects[state].isdelete)
+                    localtask.append(state, t2.listonly, isdelete=t2._objects[state].isdelete)
                 for dep in t2.dependencies:
                     localtask.dependencies.add(dep)
                 ret.insert(0, localtask)
@@ -828,7 +835,7 @@ class UOWTaskElement(object):
         return self.__preprocessed.get(processor, False)
 
     def __repr__(self):
-        return "UOWTaskElement/%d: %s/%d %s" % (id(self), self.obj.__class__.__name__, id(self.obj), (self.listonly and 'listonly' or (self.isdelete and 'delete' or 'save')) )
+        return "UOWTaskElement/%d: %s/%d %s" % (id(self), self.state.class_.__name__, id(self.state.obj()), (self.listonly and 'listonly' or (self.isdelete and 'delete' or 'save')) )
 
 class UOWDependencyProcessor(object):
     """In between the saving and deleting of objects, process
